#
# spec file for package python-beniget
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-beniget
Version:        0.4.2
Release:        1.1
Summary:        Module to extract semantic information about static Python code
License:        BSD-3-Clause
URL:            https://github.com/serge-sans-paille/beniget/
Source:         https://files.pythonhosted.org/packages/source/b/beniget/beniget-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-gast >= 0.6.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module gast >= 0.6.0}
# /SECTION
%python_subpackages

%description
A module to extract semantic information about static Python code.

%prep
%setup -q -n beniget-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v tests/*.py

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/beniget
%{python_sitelib}/beniget-%{version}*-info

%changelog
* Mon Aug 26 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- update to 0.4.2:
  * Update the way we check for locally unbound variables
  * Do not add method name to local scope
  * Fix scoping rule for comprehensions
  * Rework scope handling, esp. wrt class
  * Modernize ordered_set for Python >= 3,6 (#40)
  * Run tests on python 3.11 (#39)
  * Advertise version number
  * Accept gast 0.6.0 dependency
  * Change naming scheme of Def.name() for nodes without a name. (#100)
  * Use .<attrname> as Def.name for Attribute nodes
  * Issue SyntaxError upon unbound nonlocal
  * Support the match statement
  * Add support for TryStar from py3.11
  * Use pytest in the tox.ini tests and update other files. (#85)
  * Don't say it works with python2 in the readme (#88)
  * Fix AnnAssign (#87)
  * Drop support for Python2 (#86)
  * Fix variable arguments analysis in lambda functions. (#80)
  * Correctly handle aug assign of undefined global
  * Generalize handling of global keyword
  * Fix islive flag when there are conditional branches (#73)
  * Fix bug in warlus operator (#71)
  * Fix bug in assignments (#68)
  * Fix bug in class scope + comprehension (#69)
  * Better support for starred destructuring
  * Fix lambda function analysis (#70)
  * Fix dead code detection wrt. Raise statement
  * Do not clean lookup list too early
  * Upgrade github action
  * Remove spurious whitespaces
  * Make tests compatible with pytest
  * Require setuptools in testing for py3.12-dev
  * Get rid of RuntimeWarning: 'beniget.beniget' found in sys.modules after import of package 'beniget'...
  * Add support for PEP 563
  * Introduce Def.islive
  * Add a test
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Jan 23 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.4.1
  * require gast 0.5.0
  * no release notes
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Mon Aug 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.3.0:
  * Require gast 0.4.0
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.0:
  * python 3.8 support
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Fri Aug  2 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.1.0
